require 'omniauth-oauth2'

module OmniAuth
  module Strategies
    class Snoonet < OmniAuth::Strategies::OAuth2
      DEFAULT_SCOPE = 'info'

      option :client_options, :site          => 'https://oauth.snoonet.org',
                              :authorize_url => 'https://oauth.snoonet.org/authorize',
                              :token_url     => 'https://oauth.snoonet.org/access_token'

      uid { raw_info['name'] }

      info do
        {
          :name => raw_info['name'],
          :registered => raw_info['registered']['date'],
          :vhost => raw_info['vhost'],
          :lastquit => raw_info['lastQuit'],
          :options => raw_info['options'],
          :email => raw_info['email']
        }
      end

      extra do
        {
          :raw_info => raw_info
        }
      end

      def raw_info
        @raw_info ||= access_token.get('/api/v1/info').parsed || {}
      end

      def request_phase
        options[:authorize_params] = {
          :client_id     => options['client_id'],
          :response_type => 'code',
          :scope         => (options['scope'] || DEFAULT_SCOPE)
        }

        super
      end
    end
  end
end
